Installation
============

BindCompare is accessible through the pip installation system and the Command Line/Terminal.
If these are not setup on your device, here is a `installation-tutorial <https://python.land/virtual-environments/installing-packages-with-pip>`__ you should
follow first. To make sure that ``pip`` and ``python`` (must be version 3+) are 
properly installed, running the following should produce no errors.

.. code-block:: bash

   python3 --version
   pip --version

Once you have installed pip and python, you can run this 
command in your CLI/Terminal. 

.. code-block:: bash

   pip install --upgrade pip 
   pip install bindcompare

Now, you have installed BindCompare! This should have added the following five
commands: ``bindcompare``, ``bindexplore``, ``comparexp``, ``bindlaunch``
and ``retrievedm6``. If you want to pull the source code, directions are found
at the bottom of the documentation. 
